@@ -1345,7 +1345,7 @@ class ReferencedSegmentationFrame(ContentSequence):
 
         new_seq = ContentSequence([seg_frame_items[0], source_image_items[0]])
         new_seq.__class__ = cls
-        return new_seq
+        return cast(ReferencedSegmentationFrame, new_seq)
 
     @classmethod
     def from_segmentation(
@@ -1434,7 +1434,7 @@ class ReferencedSegmentationFrame(ContentSequence):
             if isinstance(frame_number, int):
                 frame_numbers = [frame_number]
             else:
-                frame_numbers = frame_number
+                frame_numbers = list(frame_number)
 
         number_of_frames = int(segmentation.NumberOfFrames)
         segment_numbers = []
